===============================
UserTrue
===============================



.. image:: https://pyup.io/repos/github/usertrueofficial/django-usertrue/shield.svg
     :target: https://pyup.io/repos/github/usertrueofficial/django-usertrue/
     :alt: Updates


Python UserTrue creates user analytics for websites.



Features
--------

* TODO
